@@ -20,22 +20,27 @@ from pytest_bdd import given, parsers, then, when
 from support import system
 
 language_codes = {
-    'Danish': 'da',
-    'German': 'de',
-    'Spanish': 'es',
-    'French': 'fr',
-    'Norwegian Bokmål': 'nb',
-    'Dutch': 'nl',
-    'Polish': 'pl',
-    'Portuguese': 'pt',
-    'Russian': 'ru',
-    'Swedish': 'sv',
-    'Telugu': 'te',
-    'Turkish': 'tr',
-    'Simplified Chinese': 'zh-hans',
+    'Deutsch': 'de',
+    'Nederlands': 'nl',
+    'Português': 'pt',
+    'Türkçe': 'tr',
+    'dansk': 'da',
+    'español': 'es',
+    'français': 'fr',
+    'norsk (bokmål)': 'nb',
+    'polski': 'pl',
+    'svenska': 'sv',
+    'Русский': 'ru',
+    'తెలుగు': 'te',
+    '简体中文': 'zh-hans'
 }
 
 
+@given(parsers.parse('the default app is {app_name:w}'))
+def set_default_app(browser, app_name):
+    system.set_default_app(browser, app_name)
+
+
 @given(parsers.parse('the domain name is set to {domain:w}'))
 def set_domain_name(browser, domain):
     system.set_domain_name(browser, domain)
@@ -51,6 +56,11 @@ def change_domain_name_to(browser, domain):
     system.set_domain_name(browser, domain)
 
 
+@when(parsers.parse('I change the default app to {app_name:w}'))
+def change_default_app_to(browser, app_name):
+    system.set_default_app(browser, app_name)
+
+
 @when('I change the language to <language>')
 def change_language(browser, language):
     system.set_language(browser, language_codes[language])
@@ -85,3 +95,8 @@ def create_snapshot(browser):
 def verify_snapshot_count(browser, count):
     num_snapshots = system.get_snapshot_count(browser)
     assert num_snapshots == count
+
+
+@then(parsers.parse('the default app should be {app_name:w}'))
+def default_app_should_be(browser, app_name):
+    assert system.check_home_page_redirect(browser, app_name)
