@@ -34,11 +34,10 @@ import cherrypy
 from plinth import cfg, menu, module_loader, service, setup
 
 axes.default_app_config = "plinth.axes_app_config.AppConfig"
+precedence_commandline_arguments = ["server_dir", "develop"]
 
 logger = logging.getLogger(__name__)
 
-arguments = None
-
 
 def parse_arguments():
     """Parse command line arguments"""
@@ -46,10 +45,11 @@ def parse_arguments():
         description='Core functionality and web interface for FreedomBox',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     # TODO: server_dir is actually a url prefix; use a better variable name
-    parser.add_argument('--server_dir', default=cfg.server_dir,
+    parser.add_argument('--server_dir', default=None,
                         help='web server path under which to serve')
-    parser.add_argument('--debug', action='store_true', default=cfg.debug,
-                        help='enable debugging and run server *insecurely*')
+    parser.add_argument('--develop', action='store_true', default=None,
+                        help=('run Plinth *insecurely* from current folder; '
+                            'enable auto-reloading and debugging options'))
     parser.add_argument(
         '--setup', default=False, nargs='*',
         help='run setup tasks on all essential modules and exit')
@@ -63,10 +63,7 @@ def parse_arguments():
     parser.add_argument('--list-modules', default=False, nargs='*',
                         help='list modules')
 
-    global arguments
-    arguments = parser.parse_args()
-    cfg.server_dir = arguments.server_dir
-    cfg.debug = arguments.debug
+    return parser.parse_args()
 
 
 def setup_logging():
@@ -80,8 +77,8 @@ def setup_logging():
     # Capture all Python warnings such as deprecation warnings
     logging.captureWarnings(True)
 
-    # Log all deprecation warnings when in debug mode
-    if cfg.debug:
+    # Log all deprecation warnings when in develop mode
+    if cfg.develop:
         warnings.filterwarnings('default', '', DeprecationWarning)
         warnings.filterwarnings('default', '', PendingDeprecationWarning)
         warnings.filterwarnings('default', '', ImportWarning)
@@ -97,7 +94,7 @@ def setup_server():
         'server.socket_port': cfg.port,
         'server.thread_pool': 10,
         # Avoid stating files once per second in production
-        'engine.autoreload.on': cfg.debug,
+        'engine.autoreload.on': cfg.develop,
     })
 
     application = django.core.wsgi.get_wsgi_application()
@@ -190,7 +187,7 @@ def configure_django():
         },
         'root': {
             'handlers': ['console', 'file'],
-            'level': 'DEBUG' if cfg.debug else 'INFO'
+            'level': 'DEBUG' if cfg.develop else 'INFO'
         }
     }
 
@@ -270,7 +267,7 @@ def configure_django():
                 'NAME': cfg.store_file
             }
         },
-        DEBUG=cfg.debug,
+        DEBUG=cfg.develop,
         FORCE_SCRIPT_NAME=cfg.server_dir,
         INSTALLED_APPS=applications,
         IPWARE_META_PRECEDENCE_ORDER=('HTTP_X_FORWARDED_FOR',),
@@ -313,7 +310,7 @@ def configure_django():
     logger.debug('Configured Django with applications - %s', applications)
 
     logger.debug('Creating or adding new tables to data file')
-    verbosity = 1 if cfg.debug else 0
+    verbosity = 1 if cfg.develop else 0
     django.core.management.call_command('migrate', '--fake-initial',
                                         interactive=False, verbosity=verbosity)
     os.chmod(cfg.store_file, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
@@ -377,11 +374,26 @@ def run_diagnostics_and_exit():
     sys.exit(error_code)
 
 
+def adapt_config(arguments):
+    """Give commandline arguments precedence over plinth.config entries"""
+    for argument_name in precedence_commandline_arguments:
+        argument_value = getattr(arguments, argument_name)
+        if argument_value is not None:
+            setattr(cfg, argument_name, argument_value)
+
+
 def main():
     """Intialize and start the application"""
-    cfg.read()
+    arguments = parse_arguments()
 
-    parse_arguments()
+    if arguments.develop:
+        # use the root and plinth.config of the current working directory
+        config_path, root_directory = cfg.get_fallback_config_paths()
+        cfg.read(config_path, root_directory)
+    else:
+        cfg.read()
+
+    adapt_config(arguments)
 
     setup_logging()
 
