@@ -59,7 +59,7 @@ manual_page = 'Deluge'
 def init():
     """Initialize the Deluge module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-magnet', 'deluge:index',
+    menu.add_urlname(name, 'deluge', 'deluge:index',
                      short_description)
     register_group(group)
 
@@ -91,7 +91,7 @@ def setup(helper, old_version=None):
 
 def add_shortcut():
     frontpage.add_shortcut('deluge', name, short_description, url='/deluge',
-                           login_required=True)
+                           login_required=True, allowed_groups=[group[0]])
 
 
 def is_enabled():
