@@ -24,16 +24,16 @@ import socket
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
 from plinth import action_utils, actions, cfg, frontpage
+from plinth import service as service_module
 from plinth.menu import main_menu
 from plinth.signals import (domainname_change, post_hostname_change,
                             pre_hostname_change)
 from plinth.utils import format_lazy
 
-from .manifest import clients
+from .manifest import backup, clients
 
-version = 1
+version = 2
 
 managed_services = ['ejabberd']
 
@@ -47,12 +47,13 @@ description = [
     _('XMPP is an open and standardized communication protocol. Here '
       'you can run and configure your XMPP server, called ejabberd.'),
     format_lazy(
-        _('To actually communicate, you can use the <a href="/plinth/apps/'
-          'jsxc">web client</a> or any other <a href=\'https://xmpp.org/'
+        _('To actually communicate, you can use the <a href="{jsxc_url}">'
+          'web client</a> or any other <a href=\'https://xmpp.org/'
           'software/clients\' target=\'_blank\'>XMPP client</a>. '
-          'When enabled, ejabberd can be accessed by any <a href="/plinth/sys'
-          '/users">user with a {box_name} login</a>.'), box_name=_(
-              cfg.box_name))
+          'When enabled, ejabberd can be accessed by any <a href="{users_url}">'
+          'user with a {box_name} login</a>.'), box_name=_(cfg.box_name),
+        users_url=reverse_lazy('users:index'),
+        jsxc_url=reverse_lazy('jsxc:index'))
 ]
 
 clients = clients
@@ -69,8 +70,7 @@ logger = logging.getLogger(__name__)
 def init():
     """Initialize the ejabberd module"""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-comment', 'ejabberd:index',
-                     short_description)
+    menu.add_urlname(name, 'ejabberd', 'ejabberd:index', short_description)
 
     global service
     setup_helper = globals()['setup_helper']
