@@ -15,15 +15,15 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from plinth.clients import validate
 
 clients = validate([{
-    'name':
-        _('JSXC'),
+    'name': _('JSXC'),
     'platforms': [{
         'type': 'web',
-        'url': '/plinth/apps/jsxc/jsxc/'
+        'url': reverse_lazy('jsxc:jsxc')
     }]
 }])
