@@ -24,9 +24,9 @@ from plinth import service as service_module
 from plinth import action_utils, actions, frontpage
 from plinth.menu import main_menu
 
-from .manifest import clients
+from .manifest import backup, clients
 
-version = 1
+version = 5
 
 managed_packages = ['mediawiki', 'imagemagick', 'php-sqlite3']
 
@@ -59,8 +59,7 @@ clients = clients
 def init():
     """Intialize the module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-edit', 'mediawiki:index',
-                     short_description)
+    menu.add_urlname(name, 'mediawiki', 'mediawiki:index', short_description)
 
     global service
     setup_helper = globals()['setup_helper']
@@ -77,6 +76,7 @@ def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('setup', actions.superuser_run, 'mediawiki', ['setup'])
+    helper.call('update', actions.superuser_run, 'mediawiki', ['update'])
     helper.call('enable', actions.superuser_run, 'mediawiki', ['enable'])
     global service
     if service is None:
@@ -95,9 +95,9 @@ def setup(helper, old_version=None):
 
 def add_shortcut():
     """Helper method to add a shortcut to the frontpage."""
-    frontpage.add_shortcut('mediawiki', name,
-                           short_description=short_description,
-                           url='/mediawiki', login_required=False)
+    frontpage.add_shortcut(
+        'mediawiki', name, short_description=short_description,
+        url='/mediawiki', login_required=is_private_mode_enabled())
 
 
 def is_enabled():
@@ -124,5 +124,17 @@ def diagnose():
     results.extend(
         action_utils.diagnose_url_on_all('https://{host}/mediawiki',
                                          check_certificate=False))
-
     return results
+
+
+def is_public_registration_enabled():
+    """Return whether public registration is enabled."""
+    output = actions.superuser_run('mediawiki',
+                                   ['public-registrations', 'status'])
+    return output.strip() == 'enabled'
+
+
+def is_private_mode_enabled():
+    """ Return wheter private mode is enabled or disabled"""
+    output = actions.superuser_run('mediawiki', ['private-mode', 'status'])
+    return output.strip() == 'enabled'
