@@ -27,7 +27,7 @@ from plinth import action_utils, actions, cfg, frontpage
 from plinth.menu import main_menu
 from plinth.utils import format_lazy
 
-from .manifest import clients
+from .manifest import backup, clients
 
 version = 2
 
@@ -69,7 +69,7 @@ AUG_PATH = '/files' + CONFIG_FILE + '/.anon'
 def init():
     """Initialize the module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-th-large', 'minetest:index',
+    menu.add_urlname(name, 'minetest', 'minetest:index',
                      short_description)
 
     global service
