@@ -27,7 +27,7 @@ from plinth import action_utils, actions, cfg, frontpage
 from plinth.menu import main_menu
 from plinth.utils import format_lazy
 
-from .manifest import clients
+from .manifest import backup, clients
 
 version = 1
 
@@ -62,7 +62,7 @@ CONFIG_FILE = '/etc/radicale/config'
 def init():
     """Initialize the radicale module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-calendar', 'radicale:index',
+    menu.add_urlname(name, 'radicale', 'radicale:index',
                      short_description)
 
     global service
