@@ -31,13 +31,11 @@ from .manifest import clients
 
 clients = clients
 
-version = 1
+version = 2
 
 managed_services = ['searx']
 
-managed_packages = [
-    'searx', 'uwsgi', 'uwsgi-plugin-python3', 'libapache2-mod-proxy-uwsgi'
-]
+managed_packages = ['searx', 'uwsgi', 'uwsgi-plugin-python3']
 
 name = _('Searx')
 
@@ -60,7 +58,7 @@ manual_page = 'Searx'
 def init():
     """Intialize the module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-search', 'searx:index',
+    menu.add_urlname(name, 'searx', 'searx:index',
                      short_description)
     register_group(group)
 
@@ -80,7 +78,9 @@ def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'searx', ['setup'])
-    helper.call('post', actions.superuser_run, 'searx', ['enable'])
+    if not old_version:
+        helper.call('post', actions.superuser_run, 'searx', ['enable'])
+
     global service
     if service is None:
         service = service_module.Service(managed_services[0], name, ports=[
@@ -93,7 +93,7 @@ def setup(helper, old_version=None):
 def add_shortcut():
     """Helper method to add a shortcut to the frontpage."""
     frontpage.add_shortcut('searx', name, short_description=short_description,
-                           url='/searx/', login_required=True)
+                           url='/searx/', login_required=True, allowed_groups=[group[0]])
 
 
 def get_safe_search_setting():
