@@ -19,7 +19,6 @@ Views for snapshot module.
 """
 
 import json
-import subprocess
 
 from django.contrib import messages
 from django.shortcuts import redirect
@@ -56,13 +55,13 @@ def index(request):
     else:
         form = SnapshotForm(initial=status)
 
-    return TemplateResponse(
-        request, 'snapshot.html', {
-            'title': snapshot_module.name,
-            'description': snapshot_module.description,
-            'subsubmenu': subsubmenu,
-            'form': form
-        })
+    return TemplateResponse(request, 'snapshot.html', {
+        'title': snapshot_module.name,
+        'description': snapshot_module.description,
+        'manual_page': snapshot_module.manual_page,
+        'subsubmenu': subsubmenu,
+        'form': form
+    })
 
 
 def manage(request):
@@ -77,13 +76,11 @@ def manage(request):
     has_deletable_snapshots = any(
         [snapshot for snapshot in snapshots[1:] if not snapshot['is_default']])
 
-    return TemplateResponse(
-        request, 'snapshot_manage.html', {
-            'snapshots': snapshots,
-            'has_deletable_snapshots': has_deletable_snapshots,
-            'subsubmenu': subsubmenu,
-            'manual_page': snapshot_module.manual_page,
-        })
+    return TemplateResponse(request, 'snapshot_manage.html', {
+        'snapshots': snapshots,
+        'has_deletable_snapshots': has_deletable_snapshots,
+        'subsubmenu': subsubmenu,
+    })
 
 
 def update_configuration(request, old_status, new_status):
@@ -109,10 +106,15 @@ def update_configuration(request, old_status, new_status):
                         ('number_min_age', 'NUMBER_MIN_AGE={}'),
                     ]))
 
-    command = ['snapper', 'set-config'] + list(config)
+    if old_status['enable_software_snapshots'] != new_status[
+            'enable_software_snapshots']:
+        if new_status['enable_software_snapshots'] == 'yes':
+            actions.superuser_run('snapshot', ['disable-apt-snapshot', 'no'])
+        else:
+            actions.superuser_run('snapshot', ['disable-apt-snapshot', 'yes'])
 
     try:
-        subprocess.run(command, check=True)
+        actions.superuser_run('snapshot', ['set-config', " ".join(config)])
 
         messages.success(request, _('Storage snapshots configuration updated'))
     except ActionError as exception:
@@ -127,8 +129,7 @@ def delete(request, number):
     if request.method == 'POST':
         actions.superuser_run('snapshot', ['delete', number])
         messages.success(
-            request,
-            _('Deleted snapshot #{number}.').format(number=number))
+            request, _('Deleted snapshot #{number}.').format(number=number))
         return redirect(reverse('snapshot:manage'))
 
     output = actions.superuser_run('snapshot', ['list'])
