@@ -27,7 +27,7 @@ from django.utils.translation import ugettext_lazy as _
 from plinth import actions
 from plinth.menu import main_menu
 
-version = 1
+version = 2
 
 name = _('Storage')
 
@@ -39,6 +39,8 @@ logger = logging.getLogger(__name__)
 
 manual_page = 'Storage'
 
+is_essential = True
+
 
 def init():
     """Intialize the module."""
@@ -66,7 +68,7 @@ def _get_disks_from_df():
     """Return the list of disks and free space available using 'df'."""
     command = [
         'df', '--exclude-type=tmpfs', '--exclude-type=devtmpfs',
-        '--block-size=1', '--output=source,target,fstype,size,used,avail,pcent'
+        '--block-size=1', '--output=source,fstype,size,used,avail,pcent,target'
     ]
     try:
         process = subprocess.run(command, stdout=subprocess.PIPE, check=True)
@@ -78,9 +80,9 @@ def _get_disks_from_df():
 
     disks = []
     for line in output.splitlines()[1:]:
-        parts = line.split()
-        keys = ('device', 'mount_point', 'file_system_type', 'size', 'used',
-                'free', 'percent_used')
+        parts = line.split(maxsplit=6)
+        keys = ('device', 'file_system_type', 'size', 'used',
+                'free', 'percent_used', 'mount_point')
         disk = dict(zip(keys, parts))
         disk['percent_used'] = int(disk['percent_used'].rstrip('%'))
         disk['size'] = int(disk['size'])
@@ -164,3 +166,11 @@ def format_bytes(size):
 
     size /= 1024**4
     return _('{disk_size:.1f} TiB').format(disk_size=size)
+
+
+def setup(helper, old_version=None):
+    """Expand root parition on first setup."""
+    disks = get_disks()
+    root_device = get_root_device(disks)
+    if is_expandable(root_device):
+        expand_partition(root_device)
