@@ -68,7 +68,7 @@ manual_page = 'Syncthing'
 def init():
     """Intialize the module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-refresh', 'syncthing:index',
+    menu.add_urlname(name, 'syncthing', 'syncthing:index',
                      short_description)
     register_group(group)
 
@@ -104,7 +104,8 @@ def add_shortcut():
     """Helper method to add a shortcut to the frontpage."""
     frontpage.add_shortcut('syncthing', name,
                            short_description=short_description,
-                           url='/syncthing/', login_required=True)
+                           url='/syncthing/', login_required=True,
+                           allowed_groups=[group[0]])
 
 
 def is_running():
