@@ -65,7 +65,7 @@ manual_page = 'Tor'
 def init():
     """Initialize the module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-eye-close', 'tor:index',
+    menu.add_urlname(name, 'tor', 'tor:index',
                      short_description)
 
     setup_helper = globals()['setup_helper']
@@ -74,7 +74,7 @@ def init():
     if not needs_setup:
         global socks_service
         socks_service = service_module.Service(
-            'tor-socks', _('Tor Anonymity Network'), ports=['tor-socks'],
+            'tor-socks', _('Tor Socks Proxy'), ports=['tor-socks'],
             is_external=False, is_enabled=utils.is_enabled,
             is_running=utils.is_running)
 
