@@ -60,7 +60,7 @@ manual_page = 'Transmission'
 def init():
     """Intialize the Transmission module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-save', 'transmission:index',
+    menu.add_urlname(name, 'transmission', 'transmission:index',
                      short_description)
     register_group(group)
 
@@ -102,7 +102,8 @@ def setup(helper, old_version=None):
 def add_shortcut():
     frontpage.add_shortcut('transmission', name,
                            short_description=short_description,
-                           url='/transmission', login_required=True)
+                           url='/transmission', login_required=True,
+                           allowed_groups=[group[0]])
 
 
 def is_enabled():
