@@ -18,17 +18,18 @@
 FreedomBox app to configure Tiny Tiny RSS.
 """
 
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import service as service_module
 from plinth import action_utils, actions, cfg, frontpage
+from plinth import service as service_module
 from plinth.menu import main_menu
 from plinth.modules.users import register_group
 from plinth.utils import format_lazy
 
 from .manifest import clients
 
-version = 2
+version = 3
 
 managed_services = ['tt-rss']
 
@@ -47,8 +48,8 @@ description = [
     format_lazy(
         _('When enabled, Tiny Tiny RSS will be available from <a href="/tt-'
           'rss">/tt-rss</a> path on the web server. It can be accessed by '
-          'any <a href="/plinth/sys/users">user with a {box_name} login</a>.'),
-        box_name=_(cfg.box_name)),
+          'any <a href="{users_url}">user with a {box_name} login</a>.'),
+        box_name=_(cfg.box_name), users_url=reverse_lazy('users:index')),
     format_lazy(
         _('When using a mobile or desktop application for Tiny Tiny RSS, use '
           'the URL <a href="/tt-rss-app/">/tt-rss-app</a> for connecting.'))
@@ -66,7 +67,7 @@ manual_page = 'TinyTinyRSS'
 def init():
     """Intialize the module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-envelope', 'ttrss:index',
+    menu.add_urlname(name, 'ttrss', 'ttrss:index',
                      short_description)
     register_group(group)
 
@@ -100,7 +101,8 @@ def setup(helper, old_version=None):
 def add_shortcut():
     """Add a shortcut to the front page."""
     frontpage.add_shortcut('ttrss', name, short_description=short_description,
-                           url='/tt-rss', login_required=True)
+                           url='/tt-rss', login_required=True,
+                           allowed_groups=[group[0]])
 
 
 def is_enabled():
