@@ -32,15 +32,17 @@ from plinth.modules import first_boot, users
 from plinth.modules.security import set_restricted_access
 from plinth.translation import set_language
 from plinth.utils import is_user_admin
-from plinth.models import UserProfile
+
+from . import get_last_admin_user
 
 
 def get_group_choices():
     """Return localized group description and group name in one string."""
     admin_group = ('admin', _('Access to all services and system settings'))
     users.register_group(admin_group)
-    choices = {(g[0], ('{} ({})'.format(g[1], g[0]))) for g in users.groups}
-    return sorted(list(choices), key=lambda g: g[0])
+    choices = [(k, ('{} ({})'.format(users.groups[k], k)))
+               for k in users.groups]
+    return sorted(choices, key=lambda g: g[0])
 
 
 class ValidNewUsernameCheckMixin(object):
@@ -84,8 +86,8 @@ class CreateUserForm(ValidNewUsernameCheckMixin,
     """
     groups = forms.MultipleChoiceField(
         choices=get_group_choices(), label=ugettext_lazy('Permissions'),
-        required=False,
-        widget=forms.CheckboxSelectMultiple, help_text=ugettext_lazy(
+        required=False, widget=forms.CheckboxSelectMultiple,
+        help_text=ugettext_lazy(
             'Select which services should be available to the new '
             'user. The user will be able to log in to services that '
             'support single sign-on through LDAP, if they are in the '
@@ -115,18 +117,19 @@ class CreateUserForm(ValidNewUsernameCheckMixin,
             user.userprofile.save()
 
             try:
-                actions.superuser_run('users', [
-                    'create-user', user.get_username()
-                ], input=self.cleaned_data['password1'].encode())
+                actions.superuser_run(
+                    'users',
+                    ['create-user', user.get_username()],
+                    input=self.cleaned_data['password1'].encode())
             except ActionError:
                 messages.error(self.request, _('Creating LDAP user failed.'))
 
             for group in self.cleaned_data['groups']:
                 try:
-                    actions.superuser_run('users', [
-                        'add-user-to-group',
-                        user.get_username(), group
-                    ])
+                    actions.superuser_run(
+                        'users',
+                        ['add-user-to-group',
+                         user.get_username(), group])
                 except ActionError:
                     messages.error(
                         self.request,
@@ -143,8 +146,8 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
                      plinth.forms.LanguageSelectionFormMixin, forms.ModelForm):
     """When user info is changed, also updates LDAP user."""
     ssh_keys = forms.CharField(
-        label=ugettext_lazy('SSH Keys'),
-        required=False, widget=forms.Textarea, help_text=ugettext_lazy(
+        label=ugettext_lazy('SSH Keys'), required=False, widget=forms.Textarea,
+        help_text=ugettext_lazy(
             'Setting an SSH public key will allow this user to '
             'securely log in to the system without using a '
             'password. You may enter multiple keys, one on each '
@@ -158,7 +161,7 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
         fields = ('username', 'groups', 'ssh_keys', 'language', 'is_active')
         model = User
         widgets = {
-            'groups': forms.widgets.CheckboxSelectMultiple(),
+            'groups': plinth.forms.CheckboxSelectMultipleWithReadOnly(),
         }
 
     def __init__(self, request, username, *args, **kwargs):
@@ -170,6 +173,7 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
         self.request = request
         self.username = username
         super(UserUpdateForm, self).__init__(*args, **kwargs)
+        self.is_last_admin_user = get_last_admin_user() == self.username
 
         choices = []
 
@@ -178,15 +182,24 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
             # applications not installed yet.
             if c[1] in group_choices:
                 # Replace group names with descriptions
-                choices.append((c[0], group_choices[c[1]]))
+                if c[1] == 'admin' and self.is_last_admin_user:
+                    choices.append((c[0], {
+                        'label': group_choices[c[1]],
+                        'readonly': True
+                    }))
+                else:
+                    choices.append((c[0], group_choices[c[1]]))
 
-        self.fields['groups'].label = 'Permissions'
+        self.fields['groups'].label = _('Permissions')
         self.fields['groups'].choices = choices
 
         if not is_user_admin(request):
             self.fields['is_active'].widget = forms.HiddenInput()
             self.fields['groups'].disabled = True
 
+        if self.is_last_admin_user:
+            self.fields['is_active'].disabled = True
+
     def save(self, commit=True):
         """Update LDAP user name and groups after saving user model."""
         user = super(UserUpdateForm, self).save(commit=False)
@@ -199,6 +212,7 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
 
         if commit:
             user.save()
+            self.save_m2m()
 
             output = actions.superuser_run('users',
                                            ['get-user-groups', self.username])
@@ -207,10 +221,10 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
 
             if self.username != user.get_username():
                 try:
-                    actions.superuser_run('users', [
-                        'rename-user', self.username,
-                        user.get_username()
-                    ])
+                    actions.superuser_run(
+                        'users',
+                        ['rename-user', self.username,
+                         user.get_username()])
                 except ActionError:
                     messages.error(self.request,
                                    _('Renaming LDAP user failed.'))
@@ -249,6 +263,19 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
 
         return user
 
+    def validate_last_admin_user(self, groups):
+        group_names = [group.name for group in groups]
+        if 'admin' not in group_names:
+            raise ValidationError(
+                _('Cannot delete the only administrator in the system.'))
+
+    def clean(self):
+        """Override clean to add form validation logic."""
+        cleaned_data = super().clean()
+        if self.is_last_admin_user:
+            self.validate_last_admin_user(cleaned_data.get("groups"))
+        return cleaned_data
+
 
 class UserChangePasswordForm(SetPasswordForm):
     """Custom form that also updates password for LDAP users."""
@@ -263,10 +290,10 @@ class UserChangePasswordForm(SetPasswordForm):
         user = super(UserChangePasswordForm, self).save(commit)
         if commit:
             try:
-                actions.superuser_run('users', [
-                    'set-user-password',
-                    user.get_username()
-                ], input=self.cleaned_data['new_password1'].encode())
+                actions.superuser_run(
+                    'users', ['set-user-password',
+                              user.get_username()],
+                    input=self.cleaned_data['new_password1'].encode())
             except ActionError:
                 messages.error(self.request,
                                _('Changing LDAP user password failed.'))
@@ -288,17 +315,18 @@ class FirstBootForm(ValidNewUsernameCheckMixin, auth.forms.UserCreationForm):
             first_boot.mark_step_done('users_firstboot')
 
             try:
-                actions.superuser_run('users', [
-                    'create-user', user.get_username()
-                ], input=self.cleaned_data['password1'].encode())
+                actions.superuser_run(
+                    'users',
+                    ['create-user', user.get_username()],
+                    input=self.cleaned_data['password1'].encode())
             except ActionError:
                 messages.error(self.request, _('Creating LDAP user failed.'))
 
             try:
-                actions.superuser_run('users', [
-                    'add-user-to-group',
-                    user.get_username(), 'admin'
-                ])
+                actions.superuser_run(
+                    'users',
+                    ['add-user-to-group',
+                     user.get_username(), 'admin'])
             except ActionError:
                 messages.error(self.request,
                                _('Failed to add new user to admin group.'))
